==> jc-1.4.0.tar.gz: gnu/java/io/PlatformHelper.h <==
// public class gnu.java.io.PlatformHelper

// class file dependencies
// @dep_class 73e19fd20ea8f1b1 gnu_java_io_PlatformHelper
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_io_PlatformHelper_H_
#define _JC_gnu_java_io_PlatformHelper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_io_PlatformHelper$sub_refs	_jc_gnu_java_io_PlatformHelper$sub_refs;
typedef struct _jc_gnu_java_io_PlatformHelper$sub_nonrefs	_jc_gnu_java_io_PlatformHelper$sub_nonrefs;
typedef struct _jc_gnu_java_io_PlatformHelper$refs	_jc_gnu_java_io_PlatformHelper$refs;
typedef struct _jc_gnu_java_io_PlatformHelper$nonrefs	_jc_gnu_java_io_PlatformHelper$nonrefs;
typedef struct _jc_gnu_java_io_PlatformHelper$object	_jc_gnu_java_io_PlatformHelper$object;

typedef struct _jc_gnu_java_io_PlatformHelper$fields_struct	_jc_gnu_java_io_PlatformHelper$fields_struct;
typedef const struct _jc_gnu_java_io_PlatformHelper$vmethods	_jc_gnu_java_io_PlatformHelper$vmethods;
typedef const struct _jc_gnu_java_io_PlatformHelper$vtable	_jc_gnu_java_io_PlatformHelper$vtable;
typedef const struct _jc_gnu_java_io_PlatformHelper$vtype	_jc_gnu_java_io_PlatformHelper$vtype;

// Class fields structure
struct _jc_gnu_java_io_PlatformHelper$fields_struct {
	struct _jc_java_lang_String$object	*pathSeparator;
	struct _jc_java_lang_String$object	*separator;
	jint	INITIAL__5fMAX__5fPATH;
	jchar	pathSeparatorChar;
	jchar	separatorChar;
	jboolean	isWindows;
};
extern _jc_gnu_java_io_PlatformHelper$fields_struct _jc_gnu_java_io_PlatformHelper$class_fields;

// Constructors
extern void _jc_gnu_java_io_PlatformHelper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_io_PlatformHelper$object *);

// Static methods
extern void _jc_gnu_java_io_PlatformHelper$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern jint _jc_gnu_java_io_PlatformHelper$method$beginWithRootPathPrefix$cdb3bc1f7adc8417(_jc_env *, struct _jc_java_lang_String$object *);
extern jboolean _jc_gnu_java_io_PlatformHelper$method$endWithSeparator$b2289d34bd22831a(_jc_env *, struct _jc_java_lang_String$object *);
extern jboolean _jc_gnu_java_io_PlatformHelper$method$isRootDirectory$31752a6b172f762e(_jc_env *, struct _jc_java_lang_String$object *);
extern jint _jc_gnu_java_io_PlatformHelper$method$lastIndexOfSeparator$6f4dd247c16f3a97(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_io_PlatformHelper$method$removeTailSeparator$acd998a5bd6a7a8e(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_io_PlatformHelper$method$toCanonicalForm$4d487e1635335e2c(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_io_PlatformHelper$method$toCanonicalForm$fe56e62246eb9480(_jc_env *, struct _jc_java_lang_String$object *, jchar);

// Virtual methods structure
struct _jc_gnu_java_io_PlatformHelper$vmethods {
};

// Vtable
struct _jc_gnu_java_io_PlatformHelper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_io_PlatformHelper$vmethods	gnu_java_io_PlatformHelper;
};

// Vtype
struct _jc_gnu_java_io_PlatformHelper$vtype {
	_jc_type			type;
	_jc_gnu_java_io_PlatformHelper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_io_PlatformHelper$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_io_PlatformHelper$refs {
    _jc_gnu_java_io_PlatformHelper$sub_refs	gnu_java_io_PlatformHelper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_io_PlatformHelper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_io_PlatformHelper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_io_PlatformHelper$sub_nonrefs	gnu_java_io_PlatformHelper;
};

// Object instance structure
struct _jc_gnu_java_io_PlatformHelper$object {
	_jc_gnu_java_io_PlatformHelper$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_io_PlatformHelper$vtype	*vtype;
	_jc_gnu_java_io_PlatformHelper$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_io_PlatformHelper$vtype _jc_gnu_java_io_PlatformHelper$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_io_PlatformHelper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_io_PlatformHelper$class_object;

#endif	/* _JC_gnu_java_io_PlatformHelper_H_ */

==> jc-1.4.6.tar.gz: gnu/java/io/PlatformHelper.h <==
// public class gnu.java.io.PlatformHelper

// class file dependencies
// @dep_class 73e19fd20ea8f1b1 gnu_java_io_PlatformHelper
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_io_PlatformHelper_H_
#define _JC_gnu_java_io_PlatformHelper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_io_PlatformHelper$sub_refs	_jc_gnu_java_io_PlatformHelper$sub_refs;
typedef struct _jc_gnu_java_io_PlatformHelper$sub_nonrefs	_jc_gnu_java_io_PlatformHelper$sub_nonrefs;
typedef struct _jc_gnu_java_io_PlatformHelper$refs	_jc_gnu_java_io_PlatformHelper$refs;
typedef struct _jc_gnu_java_io_PlatformHelper$nonrefs	_jc_gnu_java_io_PlatformHelper$nonrefs;
typedef struct _jc_gnu_java_io_PlatformHelper$object	_jc_gnu_java_io_PlatformHelper$object;

typedef struct _jc_gnu_java_io_PlatformHelper$fields_struct	_jc_gnu_java_io_PlatformHelper$fields_struct;
typedef const struct _jc_gnu_java_io_PlatformHelper$vmethods	_jc_gnu_java_io_PlatformHelper$vmethods;
typedef const struct _jc_gnu_java_io_PlatformHelper$vtable	_jc_gnu_java_io_PlatformHelper$vtable;
typedef const struct _jc_gnu_java_io_PlatformHelper$vtype	_jc_gnu_java_io_PlatformHelper$vtype;

// Class fields structure
struct _jc_gnu_java_io_PlatformHelper$fields_struct {
	struct _jc_java_lang_String$object	*pathSeparator;
	struct _jc_java_lang_String$object	*separator;
	jint	INITIAL__5fMAX__5fPATH;
	jchar	pathSeparatorChar;
	jchar	separatorChar;
	jboolean	isWindows;
};
extern _jc_gnu_java_io_PlatformHelper$fields_struct _jc_gnu_java_io_PlatformHelper$class_fields;

// Constructors
extern void _jc_gnu_java_io_PlatformHelper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_io_PlatformHelper$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_java_io_PlatformHelper$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_io_PlatformHelper$method$beginWithRootPathPrefix$cdb3bc1f7adc8417(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_io_PlatformHelper$method$endWithSeparator$b2289d34bd22831a(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_io_PlatformHelper$method$isRootDirectory$31752a6b172f762e(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_io_PlatformHelper$method$lastIndexOfSeparator$6f4dd247c16f3a97(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_io_PlatformHelper$method$removeTailSeparator$acd998a5bd6a7a8e(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_io_PlatformHelper$method$toCanonicalForm$4d487e1635335e2c(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_io_PlatformHelper$method$toCanonicalForm$fe56e62246eb9480(_jc_env *, struct _jc_java_lang_String$object *, jchar) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_io_PlatformHelper$vmethods {
};

// Vtable
struct _jc_gnu_java_io_PlatformHelper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_io_PlatformHelper$vmethods	gnu_java_io_PlatformHelper;
};

// Vtype
struct _jc_gnu_java_io_PlatformHelper$vtype {
	_jc_type			type;
	_jc_gnu_java_io_PlatformHelper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_io_PlatformHelper$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_io_PlatformHelper$refs {
    _jc_gnu_java_io_PlatformHelper$sub_refs	gnu_java_io_PlatformHelper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_io_PlatformHelper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_io_PlatformHelper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_io_PlatformHelper$sub_nonrefs	gnu_java_io_PlatformHelper;
};

// Object instance structure
struct _jc_gnu_java_io_PlatformHelper$object {
	_jc_gnu_java_io_PlatformHelper$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_io_PlatformHelper$vtype	*vtype;
	_jc_gnu_java_io_PlatformHelper$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_io_PlatformHelper$vtype _jc_gnu_java_io_PlatformHelper$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_io_PlatformHelper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_io_PlatformHelper$class_object;

#endif	/* _JC_gnu_java_io_PlatformHelper_H_ */
